You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nifi.apache.org by al...@apache.org on 2015/04/22 23:13:08 UTC

[18/49] incubator-nifi git commit: NIFI-271 got through nifi-api

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ComponentLog.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ComponentLog.java b/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ComponentLog.java
index c070e23..b4b3c6a 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ComponentLog.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ComponentLog.java
@@ -16,36 +16,40 @@
  */
 package org.apache.nifi.logging;
 
-
 /**
  * <p>
- * The ComponentLog provides a mechanism to ensure that all NiFi components are logging and reporting
- * information in a consistent way. When messages are logged to the ComponentLog, each message has the
- * following characteristics:
+ * The ComponentLog provides a mechanism to ensure that all NiFi components are
+ * logging and reporting information in a consistent way. When messages are
+ * logged to the ComponentLog, each message has the following characteristics:
  * </p>
- * 
+ *
  * <ul>
- *  <li>
- *      The <code>toString()</code> of the component is automatically prepended to the message so that it is clear
- *      which component is providing the information. This is important, since a single component may have many
- *      different instances within the same NiFi instance.
- *  </li>
- *  <li>
- *      If the last value in an Object[] argument that is passed to the logger is a Throwable, then the logged message
- *      will include a <code>toString()</code> of the Throwable; in addition, if the component's logger is set to
- *      DEBUG level via the logback configuration, the Stacktrace will also be logged. This provides a mechanism to easily
- *      enable stacktraces in the logs when they are desired without filling the logs with unneeded stack traces for messages
- *      that end up occurring often.
- *  </li>
- *  <li>
- *      Any message that is logged with a Severity level that meets or exceeds the configured Bulletin Level for that component
- *      will also cause a Bulletin to be generated, so that the message is visible in the UI, allowing Dataflow Managers
- *      to understand that a problem exists and what the issue is.
- *  </li>
+ * <li>
+ * The <code>toString()</code> of the component is automatically prepended to
+ * the message so that it is clear which component is providing the information.
+ * This is important, since a single component may have many different instances
+ * within the same NiFi instance.
+ * </li>
+ * <li>
+ * If the last value in an Object[] argument that is passed to the logger is a
+ * Throwable, then the logged message will include a <code>toString()</code> of
+ * the Throwable; in addition, if the component's logger is set to DEBUG level
+ * via the logback configuration, the Stacktrace will also be logged. This
+ * provides a mechanism to easily enable stacktraces in the logs when they are
+ * desired without filling the logs with unneeded stack traces for messages that
+ * end up occurring often.
+ * </li>
+ * <li>
+ * Any message that is logged with a Severity level that meets or exceeds the
+ * configured Bulletin Level for that component will also cause a Bulletin to be
+ * generated, so that the message is visible in the UI, allowing Dataflow
+ * Managers to understand that a problem exists and what the issue is.
+ * </li>
  * </ul>
- * 
+ *
  */
 public interface ComponentLog {
+
     void warn(String msg, Throwable t);
 
     void warn(String msg, Object[] os);

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ProcessorLog.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ProcessorLog.java b/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ProcessorLog.java
index 0d66d85..a90ee26 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ProcessorLog.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/logging/ProcessorLog.java
@@ -16,14 +16,14 @@
  */
 package org.apache.nifi.logging;
 
-
 /**
- * The ProcessorLog is an extension of ComponentLog but provides no additional functionality.
- * It exists because ProcessorLog was created first,
- * but when Controller Services and Reporting Tasks began to be used more heavily loggers
- * were needed for them as well. We did not want to return a ProcessorLog to a ControllerService
- * or a ReportingTask, so all of the methods were moved to a higher interface named ComponentLog.
- * However, we kept the ProcessorLog interface around in order to maintain backward compatibility.
+ * The ProcessorLog is an extension of ComponentLog but provides no additional
+ * functionality. It exists because ProcessorLog was created first, but when
+ * Controller Services and Reporting Tasks began to be used more heavily loggers
+ * were needed for them as well. We did not want to return a ProcessorLog to a
+ * ControllerService or a ReportingTask, so all of the methods were moved to a
+ * higher interface named ComponentLog. However, we kept the ProcessorLog
+ * interface around in order to maintain backward compatibility.
  */
 public interface ProcessorLog extends ComponentLog {
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/AbstractSessionFactoryProcessor.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/AbstractSessionFactoryProcessor.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/AbstractSessionFactoryProcessor.java
index f13a143..2695dcd 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/AbstractSessionFactoryProcessor.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/AbstractSessionFactoryProcessor.java
@@ -41,7 +41,6 @@ import org.apache.nifi.logging.ProcessorLog;
  * <p>
  * Thread safe</p>
  *
- * @author none
  */
 public abstract class AbstractSessionFactoryProcessor extends AbstractConfigurableComponent implements Processor {
 
@@ -62,10 +61,8 @@ public abstract class AbstractSessionFactoryProcessor extends AbstractConfigurab
     }
 
     /**
-     * Returns the {@link ControllerServiceLookup} that was passed to the
+     * @return the {@link ControllerServiceLookup} that was passed to the
      * {@link #init(ProcessorInitializationContext)} method
-     *
-     * @return
      */
     protected final ControllerServiceLookup getControllerServiceLookup() {
         return serviceLookup;
@@ -83,17 +80,15 @@ public abstract class AbstractSessionFactoryProcessor extends AbstractConfigurab
     /**
      * Provides subclasses the ability to perform initialization logic
      *
-     * @param context
+     * @param context in which to perform initialization
      */
     protected void init(final ProcessorInitializationContext context) {
         // Provided for subclasses to override
     }
 
     /**
-     * Returns <code>true</code> if the processor is scheduled to run,
+     * @return <code>true</code> if the processor is scheduled to run,
      * <code>false</code> otherwise
-     *
-     * @return
      */
     protected final boolean isScheduled() {
         return scheduled;

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/DataUnit.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/DataUnit.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/DataUnit.java
index dc0a66f..4980b97 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/DataUnit.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/DataUnit.java
@@ -21,9 +21,6 @@ import java.util.regex.Pattern;
 
 public enum DataUnit {
 
-    // 1024 * 1024 = 
-    // 1024 * 1024 * 1024
-    // 1024 * 1024 * 1024 * 1024 
     /**
      * Bytes
      */

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/FlowFileFilter.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/FlowFileFilter.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/FlowFileFilter.java
index 20147ca..3bd6546 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/FlowFileFilter.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/FlowFileFilter.java
@@ -35,8 +35,10 @@ public interface FlowFileFilter {
      * whether or not the Processor is interested in filtering additional
      * FlowFiles
      *
-     * @param flowFile
-     * @return
+     * @param flowFile to apply the filter to
+     * @return true if the given FlowFile should be selected and
+     * if Processor is interested in filtering additional
+     * FlowFiles
      */
     FlowFileFilterResult filter(FlowFile flowFile);
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessContext.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessContext.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessContext.java
index 7fa183f..c61a318 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessContext.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessContext.java
@@ -39,8 +39,8 @@ public interface ProcessContext {
      * Retrieves the current value set for the given descriptor, if a value is
      * set - else uses the descriptor to determine the appropriate default value
      *
-     * @param descriptor
-     * @return
+     * @param descriptor to lookup the value of
+     * @return the property value of the given descriptor
      */
     PropertyValue getProperty(PropertyDescriptor descriptor);
 
@@ -48,8 +48,8 @@ public interface ProcessContext {
      * Retrieves the current value set for the given descriptor, if a value is
      * set - else uses the descriptor to determine the appropriate default value
      *
-     * @param propertyName
-     * @return
+     * @param propertyName of the property to lookup the value for
+     * @return property value as retrieved by property name
      */
     PropertyValue getProperty(String propertyName);
 
@@ -57,8 +57,9 @@ public interface ProcessContext {
      * Creates and returns a {@link PropertyValue} object that can be used for
      * evaluating the value of the given String
      *
-     * @param rawValue
-     * @return
+     * @param rawValue the raw input before any property evaluation has occurred
+     * @return a {@link PropertyValue} object that can be used for
+     * evaluating the value of the given String
      */
     PropertyValue newPropertyValue(String rawValue);
 
@@ -89,11 +90,9 @@ public interface ProcessContext {
     String getAnnotationData();
 
     /**
-     * Returns a Map of all PropertyDescriptors to their configured values. This
+     * @return a Map of all PropertyDescriptors to their configured values. This
      * Map may or may not be modifiable, but modifying its values will not
      * change the values of the processor's properties
-     *
-     * @return
      */
     Map<PropertyDescriptor, String> getProperties();
 
@@ -101,8 +100,8 @@ public interface ProcessContext {
      * Encrypts the given value using the password provided in the NiFi
      * Properties
      *
-     * @param unencrypted
-     * @return
+     * @param unencrypted plaintext value
+     * @return encrypted value
      */
     String encrypt(String unencrypted);
 
@@ -110,19 +109,17 @@ public interface ProcessContext {
      * Decrypts the given value using the password provided in the NiFi
      * Properties
      *
-     * @param encrypted
-     * @return
+     * @param encrypted the encrypted value
+     * @return the plaintext value
      */
     String decrypt(String encrypted);
 
     /**
-     * Provides a {@code ControllerServiceLookup} that can be used to obtain a
+     * @return a {@code ControllerServiceLookup} that can be used to obtain a
      * Controller Service
-     *
-     * @return
      */
     ControllerServiceLookup getControllerServiceLookup();
-    
+
     /**
      * @return the set of all relationships for which space is available to
      * receive new objects

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessSession.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/Processor.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/Processor.java
index eff5b59..fcb04ea 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/Processor.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/Processor.java
@@ -54,7 +54,7 @@ public interface Processor extends ConfigurableComponent {
      * Provides the processor with access to objects that may be of use
      * throughout the life of the Processor
      *
-     * @param context
+     * @param context of initialization
      */
     void initialize(ProcessorInitializationContext context);
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessorInitializationContext.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessorInitializationContext.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessorInitializationContext.java
index 6e3679c..7b09e1b 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessorInitializationContext.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessorInitializationContext.java
@@ -29,25 +29,19 @@ import org.apache.nifi.logging.ProcessorLog;
 public interface ProcessorInitializationContext {
 
     /**
-     * Returns the unique identifier for this processor
-     *
-     * @return
+     * @return the unique identifier for this processor
      */
     String getIdentifier();
 
     /**
-     * Returns a {@link ProcessorLog} that is tied to this processor that can be
+     * @return a {@link ProcessorLog} that is tied to this processor that can be
      * used to log events
-     *
-     * @return
      */
     ProcessorLog getLogger();
 
     /**
-     * Returns the {@link ControllerServiceLookup} which can be used to obtain
+     * @return the {@link ControllerServiceLookup} which can be used to obtain
      * Controller Services
-     *
-     * @return
      */
     ControllerServiceLookup getControllerServiceLookup();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/CapabilityDescription.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/CapabilityDescription.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/CapabilityDescription.java
index fad1ebb..8ca8290 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/CapabilityDescription.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/CapabilityDescription.java
@@ -28,7 +28,8 @@ import java.lang.annotation.Target;
  * provided. This description can be provided to a user in logs, UI, etc.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.documentation.CapabilityDescription}
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.documentation.CapabilityDescription}
  * annotation.
  */
 @Documented

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/EventDriven.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/EventDriven.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/EventDriven.java
index 6152168..53f1d72 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/EventDriven.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/EventDriven.java
@@ -39,8 +39,8 @@ import java.lang.annotation.Target;
  * </p>
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.behavior.EventDriven}
- * annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.behavior.EventDriven} annotation.
  */
 @Documented
 @Target({ElementType.TYPE})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnAdded.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnAdded.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnAdded.java
index b2ea5eb..1c2b709 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnAdded.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnAdded.java
@@ -32,7 +32,8 @@ import java.lang.annotation.Target;
  * be added to the graph.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.lifecycle.OnAdded} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.lifecycle.OnAdded} annotation.
  */
 @Documented
 @Target({ElementType.METHOD})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnRemoved.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnRemoved.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnRemoved.java
index fae4e34..239a449 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnRemoved.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnRemoved.java
@@ -33,7 +33,8 @@ import java.lang.annotation.Target;
  * be removed from the graph.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.lifecycle.OnRemoved} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.lifecycle.OnRemoved} annotation.
  */
 @Documented
 @Target({ElementType.METHOD})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnScheduled.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnScheduled.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnScheduled.java
index ed65ce0..3a716e6 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnScheduled.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnScheduled.java
@@ -35,8 +35,9 @@ import java.lang.annotation.Target;
  * be scheduled to run.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.lifecycle.OnScheduled} annotation.
-*/
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.lifecycle.OnScheduled} annotation.
+ */
 @Documented
 @Target({ElementType.METHOD})
 @Retention(RetentionPolicy.RUNTIME)

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnShutdown.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnShutdown.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnShutdown.java
index bb38221..22ecc0b 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnShutdown.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnShutdown.java
@@ -29,7 +29,8 @@ import java.lang.annotation.Target;
  * most once for each processor instance in a process lifetime.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.lifecycle.OnShutdown} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.lifecycle.OnShutdown} annotation.
  */
 @Documented
 @Target({ElementType.METHOD})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnStopped.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnStopped.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnStopped.java
index 3f61850..223868e 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnStopped.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnStopped.java
@@ -46,7 +46,8 @@ import java.lang.annotation.Target;
  * </p>
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.lifecycle.OnStopped} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.lifecycle.OnStopped} annotation.
  */
 @Documented
 @Target({ElementType.METHOD})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnUnscheduled.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnUnscheduled.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnUnscheduled.java
index a9b94fc..a231435 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnUnscheduled.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/OnUnscheduled.java
@@ -37,7 +37,8 @@ import java.lang.annotation.Target;
  * be scheduled to run.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.lifecycle.OnUnscheduled} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.lifecycle.OnUnscheduled} annotation.
  */
 @Documented
 @Target({ElementType.METHOD})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SideEffectFree.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SideEffectFree.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SideEffectFree.java
index 281b38d..99980c5 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SideEffectFree.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SideEffectFree.java
@@ -36,7 +36,8 @@ import java.lang.annotation.Target;
  * repeated (implied idempotent behavior).
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.behavior.SideEffectFree} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.behavior.SideEffectFree} annotation.
  */
 @Documented
 @Target({ElementType.TYPE})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SupportsBatching.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SupportsBatching.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SupportsBatching.java
index 2b89e4e..7335a55 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SupportsBatching.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/SupportsBatching.java
@@ -41,7 +41,8 @@ import java.lang.annotation.Target;
  * from a remote source.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.behavior.SupportsBatching} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.behavior.SupportsBatching} annotation.
  */
 @Documented
 @Target({ElementType.TYPE})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/Tags.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/Tags.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/Tags.java
index c06302d..81428d7 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/Tags.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/Tags.java
@@ -29,9 +29,8 @@ import java.lang.annotation.Target;
  * any way but serve as additional documentation and can be used to sort/filter
  * Processors.
  *
- * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.documentation.Tags}
- * annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.documentation.Tags} annotation.
  */
 @Documented
 @Target({ElementType.TYPE})
@@ -40,8 +39,5 @@ import java.lang.annotation.Target;
 @Deprecated
 public @interface Tags {
 
-    /**
-     * @return all tag values associated with the given processor
-     */
     public String[] value();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerSerially.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerSerially.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerSerially.java
index 0b3d1e6..52c1079 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerSerially.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerSerially.java
@@ -30,8 +30,9 @@ import java.lang.annotation.Target;
  * execution.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.behavior.TriggerSerially} annotation.
-*/
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.behavior.TriggerSerially} annotation.
+ */
 @Documented
 @Target({ElementType.TYPE})
 @Retention(RetentionPolicy.RUNTIME)

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenAnyDestinationAvailable.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenAnyDestinationAvailable.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenAnyDestinationAvailable.java
index 52f6c5e..8e8e5df 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenAnyDestinationAvailable.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenAnyDestinationAvailable.java
@@ -30,7 +30,9 @@ import java.lang.annotation.Target;
  * destinations report that they have available space.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.behavior.TriggerWhenAnyDestinationAvailable} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.behavior.TriggerWhenAnyDestinationAvailable}
+ * annotation.
  */
 @Documented
 @Target({ElementType.TYPE})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenEmpty.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenEmpty.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenEmpty.java
index 1d2f755..f27b111 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenEmpty.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/annotation/TriggerWhenEmpty.java
@@ -32,7 +32,8 @@ import java.lang.annotation.Target;
  * their queue or they present this annotation.
  *
  * @author none
- * @deprecated This Annotation has been replaced by the {@link org.apache.nifi.annotation.behavior.TriggerWhenEmpty} annotation.
+ * @deprecated This Annotation has been replaced by the
+ * {@link org.apache.nifi.annotation.behavior.TriggerWhenEmpty} annotation.
  */
 @Documented
 @Target({ElementType.TYPE})

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/InputStreamCallback.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/InputStreamCallback.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/InputStreamCallback.java
index e227156..e850684 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/InputStreamCallback.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/InputStreamCallback.java
@@ -30,8 +30,8 @@ public interface InputStreamCallback {
      * automatically opened and closed though it is ok to close the stream
      * manually.
      *
-     * @param in
-     * @throws IOException
+     * @param in the stream to read bytes from
+     * @throws IOException if issues reading from the underlying stream
      */
     void process(InputStream in) throws IOException;
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/OutputStreamCallback.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/OutputStreamCallback.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/OutputStreamCallback.java
index a991a1c..e37c376 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/OutputStreamCallback.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/OutputStreamCallback.java
@@ -31,8 +31,8 @@ public interface OutputStreamCallback {
      * manually - and quite important if any streams wrapping these streams open
      * resources which should be cleared.
      *
-     * @param out
-     * @throws IOException
+     * @param out the stream to write bytes to
+     * @throws IOException if issues writing to output stream
      */
     void process(OutputStream out) throws IOException;
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/StreamCallback.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/StreamCallback.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/StreamCallback.java
index 2d47c89..54f0e3b 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/StreamCallback.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/io/StreamCallback.java
@@ -20,10 +20,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-/**
- *
- * @author unattributed
- */
 public interface StreamCallback {
 
     /**
@@ -32,9 +28,9 @@ public interface StreamCallback {
      * manually - and quite important if any streams wrapping these streams open
      * resources which should be cleared.
      *
-     * @param in
-     * @param out
-     * @throws IOException
+     * @param in the stream to read bytes from
+     * @param out the stream to write bytes to
+     * @throws IOException if issues occur reading or writing the underlying streams
      */
     void process(InputStream in, OutputStream out) throws IOException;
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventBuilder.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventBuilder.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventBuilder.java
index 4978eba..0ffccd5 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventBuilder.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventBuilder.java
@@ -28,8 +28,8 @@ public interface ProvenanceEventBuilder {
     /**
      * Sets the type of {@link ProvenanceEventRecord}
      *
-     * @param eventType
-     * @return
+     * @param eventType of the event
+     * @return the builder
      */
     ProvenanceEventBuilder setEventType(ProvenanceEventType eventType);
 
@@ -38,15 +38,15 @@ public interface ProvenanceEventBuilder {
      * given event
      *
      * @param event the event from which to populate the Builders values
-     * @return
+     * @return the builder
      */
     ProvenanceEventBuilder fromEvent(ProvenanceEventRecord event);
 
     /**
      * Sets the date and time at which the FlowFile entered the flow
      *
-     * @param entryDate
-     * @return
+     * @param entryDate of the flow file
+     * @return the builder
      */
     ProvenanceEventBuilder setFlowFileEntryDate(long entryDate);
 
@@ -54,8 +54,8 @@ public interface ProvenanceEventBuilder {
      * Sets the Lineage Identifiers. This is a set of all FlowFile UUID's that
      * were involved in making this event occur.
      *
-     * @param lineageIdentifiers
-     * @return
+     * @param lineageIdentifiers of the flowfiles in this event
+     * @return the builder
      */
     ProvenanceEventBuilder setLineageIdentifiers(Set<String> lineageIdentifiers);
 
@@ -63,12 +63,12 @@ public interface ProvenanceEventBuilder {
      * Sets the Content Claim that the FlowFile was previously associated with
      * before this event occurred.
      *
-     * @param container
-     * @param section
-     * @param identifier
-     * @param offset
-     * @param size
-     * @return
+     * @param container for previous content
+     * @param section for previous content
+     * @param identifier for previous content
+     * @param offset for previous content
+     * @param size for previous content
+     * @return the builder
      */
     ProvenanceEventBuilder setPreviousContentClaim(String container, String section, String identifier, Long offset, long size);
 
@@ -76,12 +76,12 @@ public interface ProvenanceEventBuilder {
      * Sets the Content Claim that the FlowFile is associated with as a result
      * of this event
      *
-     * @param container
-     * @param section
-     * @param identifier
-     * @param offset
-     * @param size
-     * @return
+     * @param container for resulting content
+     * @param section for resulting content
+     * @param identifier for resulting content
+     * @param offset for resulting content
+     * @param size for resulting content
+     * @return the builder
      */
     ProvenanceEventBuilder setCurrentContentClaim(String container, String section, String identifier, Long offset, long size);
 
@@ -89,8 +89,8 @@ public interface ProvenanceEventBuilder {
      * Sets the identifier of the FlowFile Queue from which the FlowFile was
      * pulled
      *
-     * @param identifier
-     * @return
+     * @param identifier of the source queue
+     * @return the builder
      */
     ProvenanceEventBuilder setSourceQueueIdentifier(String identifier);
 
@@ -99,28 +99,28 @@ public interface ProvenanceEventBuilder {
      * occurred and any attributes that were added or updated as a result of
      * this event.
      *
-     * @param previousAttributes
+     * @param previousAttributes Map of all attributes before the event occurred
      * @param updatedAttributes Map containing all attributes that were added or
      * updated. If any entry has a value of <code>null</code>, that attribute is
      * considered removed
      *
-     * @return
+     * @return the builder
      */
     ProvenanceEventBuilder setAttributes(Map<String, String> previousAttributes, Map<String, String> updatedAttributes);
 
     /**
      * Sets the UUID to associate with the FlowFile
      *
-     * @param uuid
-     * @return
+     * @param uuid of the flowfile
+     * @return the builder
      */
     ProvenanceEventBuilder setFlowFileUUID(String uuid);
 
     /**
      * Sets the time at which the Provenance Event took place
      *
-     * @param eventTime
-     * @return
+     * @param eventTime time of the event
+     * @return the builder
      */
     ProvenanceEventBuilder setEventTime(long eventTime);
 
@@ -128,16 +128,16 @@ public interface ProvenanceEventBuilder {
      * Sets the amount of time that was required in order to perform the
      * function referred to by this event
      *
-     * @param millis
-     * @return
+     * @param millis of the event
+     * @return the builder
      */
     ProvenanceEventBuilder setEventDuration(long millis);
 
     /**
      * Sets the time at which the FlowFile's lineage began
      *
-     * @param startDate
-     * @return
+     * @param startDate start date of the event
+     * @return the builder
      */
     ProvenanceEventBuilder setLineageStartDate(long startDate);
 
@@ -145,8 +145,8 @@ public interface ProvenanceEventBuilder {
      * Sets the unique identifier of the NiFi Component (such as a
      * {@link Processor}) that is generating the Event
      *
-     * @param componentId
-     * @return
+     * @param componentId that produced the event
+     * @return the builder
      */
     ProvenanceEventBuilder setComponentId(String componentId);
 
@@ -154,8 +154,8 @@ public interface ProvenanceEventBuilder {
      * Sets the type of the Component that is generating the Event. For
      * {@link Processor}s, this is the Simple Class Name of the Processor.
      *
-     * @param componentType
-     * @return
+     * @param componentType of the component that made the event
+     * @return the builder
      */
     ProvenanceEventBuilder setComponentType(String componentType);
 
@@ -167,8 +167,8 @@ public interface ProvenanceEventBuilder {
      * and {@link ProvenanceEventType#SEND} and will be ignored for any other
      * event types.
      *
-     * @param sourceSystemFlowFileIdentifier
-     * @return
+     * @param sourceSystemFlowFileIdentifier identifier the remote system used
+     * @return the builder
      */
     ProvenanceEventBuilder setSourceSystemFlowFileIdentifier(String sourceSystemFlowFileIdentifier);
 
@@ -184,8 +184,8 @@ public interface ProvenanceEventBuilder {
      * and {@link ProvenanceEventType#SEND} and will be ignored for any other
      * event types.
      *
-     * @param transitUri
-     * @return
+     * @param transitUri of the event
+     * @return the builder
      */
     ProvenanceEventBuilder setTransitUri(String transitUri);
 
@@ -194,13 +194,13 @@ public interface ProvenanceEventBuilder {
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE}
      *
-     * This is valid only for null null null null null     {@link ProvenanceEventType#SPAWN}, 
+     * This is valid only for {@link ProvenanceEventType#SPAWN},
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE} events and will be ignored for any
      * other event types.
      *
-     * @param parent
-     * @return
+     * @param parent flowfile that this event is derived from
+     * @return the builder
      */
     ProvenanceEventBuilder addParentFlowFile(FlowFile parent);
 
@@ -209,13 +209,13 @@ public interface ProvenanceEventBuilder {
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE}
      *
-     * This is valid only for null null null null null     {@link ProvenanceEventType#SPAWN}, 
+     * This is valid only for {@link ProvenanceEventType#SPAWN},
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE} events and will be ignored for any
      * other event types.
      *
-     * @param parent
-     * @return
+     * @param parent previous parent of this event
+     * @return the builder
      */
     ProvenanceEventBuilder removeParentFlowFile(FlowFile parent);
 
@@ -224,13 +224,13 @@ public interface ProvenanceEventBuilder {
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE}
      *
-     * This is valid only for null null null null null     {@link ProvenanceEventType#SPAWN}, 
+     * This is valid only for {@link ProvenanceEventType#SPAWN},
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE} events and will be ignored for any
      * other event types.
      *
-     * @param child
-     * @return
+     * @param child the child to add
+     * @return the builder
      */
     ProvenanceEventBuilder addChildFlowFile(FlowFile child);
 
@@ -239,13 +239,13 @@ public interface ProvenanceEventBuilder {
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE}
      *
-     * This is valid only for null null null null null     {@link ProvenanceEventType#SPAWN}, 
+     * This is valid only for {@link ProvenanceEventType#SPAWN},
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, and
      * {@link ProvenanceEventType#CLONE} events and will be ignored for any
      * other event types.
      *
-     * @param child
-     * @return
+     * @param child to remove
+     * @return the builder
      */
     ProvenanceEventBuilder removeChildFlowFile(FlowFile child);
 
@@ -259,8 +259,8 @@ public interface ProvenanceEventBuilder {
      * This is valid only for {@link ProvenanceEventType#ADDINFO} events and
      * will be ignored for any other event types.
      *
-     * @param alternateIdentifierUri
-     * @return
+     * @param alternateIdentifierUri another identifier of the flowfile this event is for
+     * @return the builder
      */
     ProvenanceEventBuilder setAlternateIdentifierUri(String alternateIdentifierUri);
 
@@ -268,8 +268,8 @@ public interface ProvenanceEventBuilder {
      * Sets the details for this event. This is a free-form String that can
      * contain any information that is relevant to this event.
      *
-     * @param details
-     * @return
+     * @param details a description of the event
+     * @return the builder
      */
     ProvenanceEventBuilder setDetails(String details);
 
@@ -279,8 +279,8 @@ public interface ProvenanceEventBuilder {
      * {@link ProvenanceEventType#ROUTE} events and will be ignored for any
      * other event types.
      *
-     * @param relationship
-     * @return
+     * @param relationship to which flowfiles in this event were routed
+     * @return the builder
      */
     ProvenanceEventBuilder setRelationship(Relationship relationship);
 
@@ -288,8 +288,8 @@ public interface ProvenanceEventBuilder {
      * Populates the builder with as much information as it can from the given
      * FlowFile
      *
-     * @param flowFile
-     * @return
+     * @param flowFile to source attributes for this event from
+     * @return the builder
      */
     ProvenanceEventBuilder fromFlowFile(FlowFile flowFile);
 
@@ -301,7 +301,7 @@ public interface ProvenanceEventBuilder {
      * depend on the {@link ProvevenanceEventRepository} to generate the unique
      * identifier.
      *
-     * @return
+     * @return the event
      */
     ProvenanceEventRecord build();
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRecord.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRecord.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRecord.java
index 4b1b1a0..dc251b3 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRecord.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRecord.java
@@ -26,26 +26,20 @@ import java.util.Set;
 public interface ProvenanceEventRecord {
 
     /**
-     * Returns a unique ID for this Provenance Event. Depending on the
+     * @return a unique ID for this Provenance Event. Depending on the
      * implementation, the Event ID may be set to -1 until the event has been
      * added to the {@link ProvenanceEventRepository}
-     *
-     * @return
      */
     long getEventId();
 
     /**
-     * Returns the time at which this Provenance Event was created, as the
+     * @return the time at which this Provenance Event was created, as the
      * number of milliseconds since epoch
-     *
-     * @return
      */
     long getEventTime();
 
     /**
-     * Returns the EntryDate of the FlowFile to which this Event is associated
-     *
-     * @return
+     * @return the EntryDate of the FlowFile to which this Event is associated
      */
     long getFlowFileEntryDate();
 
@@ -61,236 +55,181 @@ public interface ProvenanceEventRecord {
     Set<String> getLineageIdentifiers();
 
     /**
-     * Returns the size of the FlowFile to which this Event is associated
-     *
-     * @return
+     * @return the size of the FlowFile to which this Event is associated
      */
     long getFileSize();
 
     /**
-     * Returns the previous size of the FlowFile to which this Event is
+     * @return the previous size of the FlowFile to which this Event is
      * associated, if the FlowFile previously had content and its size was
      * known; otherwise, returns <code>null</code>
-     *
-     * @return
      */
     Long getPreviousFileSize();
 
     /**
-     * Returns the amount of time in milliseconds that elapsed while performing
-     * this event. If not populated, the value -1 will be returned.
-     *
-     * @return
+     * @return the amount of time in milliseconds that elapsed while performing
+     * this event. If not populated, the value -1 will be returned
      */
     long getEventDuration();
 
     /**
-     * Returns the type of this Provenance Event
-     *
-     * @return
+     * @return the type of this Provenance Event
      */
     ProvenanceEventType getEventType();
 
     /**
-     * Returns all FlowFile attributes that were associated with the FlowFile at
+     * @return all FlowFile attributes that were associated with the FlowFile at
      * the time that this ProvenanceEvent was created
-     *
-     * @return
      */
     Map<String, String> getAttributes();
 
     /**
-     * Returns all FlowFile attributes that existed on the FlowFile before this
+     * @return all FlowFile attributes that existed on the FlowFile before this
      * event occurred
-     *
-     * @return
      */
     Map<String, String> getPreviousAttributes();
 
     /**
-     * Returns all FlowFile attributes that were updated as a result of this
+     * @return all FlowFile attributes that were updated as a result of this
      * event
-     *
-     * @return
      */
     Map<String, String> getUpdatedAttributes();
 
     /**
-     * Returns the ID of the Processor/component that created this Provenance
+     * @return the ID of the Processor/component that created this Provenance
      * Event
-     *
-     * @return
      */
     String getComponentId();
 
     /**
-     * Returns the fully-qualified Class Name of the Processor/component that
+     * @return the fully-qualified Class Name of the Processor/component that
      * created this Provenance Event
-     *
-     * @return
      */
     String getComponentType();
 
     /**
-     * Returns a URI that provides information about the System and Protocol
+     * @return a URI that provides information about the System and Protocol
      * information over which the transfer occurred. The intent of this field is
      * such that both the sender and the receiver can publish the events to an
      * external Enterprise-wide system that is then able to correlate the SEND
      * and RECEIVE events.
-     *
-     * @return
      */
     String getTransitUri();
 
     /**
-     * Returns the UUID that the Source System used to refer to this data; this
-     * is applicable only when the {@link ProvenanceEventType} is of type
-     * {@link ProvenanceEventType#RECEIVE RECEIVE}.
-     *
      * Since the receiving system will usually refer to the data using a
      * different identifier than the source system, this information is used to
      * correlate the receive system's FlowFile with the sending system's data
      *
-     * @return
+     * @return the UUID that the Source System used to refer to this data; this
+     * is applicable only when the {@link ProvenanceEventType} is of type
+     * {@link ProvenanceEventType#RECEIVE RECEIVE}
      */
     String getSourceSystemFlowFileIdentifier();
 
     /**
-     * Returns the UUID of the FlowFile with which this Event is associated
-     *
-     * @return
+     * @return the UUID of the FlowFile with which this Event is associated
      */
     String getFlowFileUuid();
 
     /**
-     * Returns the UUID's of all Parent FlowFiles. This is applicable only when
+     * @return the UUID's of all Parent FlowFiles. This is applicable only when
      * the {@link ProvenanceEventType} is of type
-     * {@link ProvenanceEventType#SPAWN SPAWN}.
-     *
-     * @return
+     * {@link ProvenanceEventType#SPAWN SPAWN}
      */
     List<String> getParentUuids();
 
     /**
-     * Returns the UUID's of all Child FlowFiles. This is applicable only when
+     * @return the UUID's of all Child FlowFiles. This is applicable only when
      * the {@link ProvenanceEventType} is of type
-     * {@link ProvenanceEventType#SPAWN SPAWN}.
-     *
-     * @return
+     * {@link ProvenanceEventType#SPAWN SPAWN}
      */
     List<String> getChildUuids();
 
     /**
-     * Returns the Alternate Identifier associated with the FlowFile with which
+     * @return the Alternate Identifier associated with the FlowFile with which
      * this Event is associated. This is applicable only when the
      * {@link ProvenanceEventType} is of type
-     * {@link ProvenanceEventType#ADDINFO}.
-     *
-     * @return
+     * {@link ProvenanceEventType#ADDINFO}
      */
     String getAlternateIdentifierUri();
 
     /**
-     * Returns the details for this record, if any were supplied. Otherwise,
+     * @return the details for this record, if any were supplied. Otherwise,
      * returns <code>null</code>
-     *
-     * @return
-     *
      */
     String getDetails();
 
     /**
-     * Returns the relationship to which this record was routed if the event
+     * @return the relationship to which this record was routed if the event
      * type is {@link ProvenanceEventType#ROUTE}. The relationship is applicable
-     * only to this type.
-     *
-     * @return
-     *
+     * only to this type
      */
     String getRelationship();
 
     /**
-     * Returns the identifier of the queue from which the FlowFile was taken, if
+     * @return the identifier of the queue from which the FlowFile was taken, if
      * any. If the FlowFile is created as a result of this event (in this case,
-     * the Event Type is one of null null null null null     {@link ProvenanceEventType#CREATE}, {@link ProvenanceEventType#RECEIVE},
+     * the Event Type is one of null null null null null null null null     {@link ProvenanceEventType#CREATE}, {@link ProvenanceEventType#RECEIVE},
      * {@link ProvenanceEventType#FORK}, {@link ProvenanceEventType#JOIN}, or
      * {@link ProvenanceEventType#CLONE}), or if the queue identifier is
-     * unknown, then this method will return <code>null</code>.
-     *
-     * @return
+     * unknown, then this method will return <code>null</code>
      *
      */
     String getSourceQueueIdentifier();
 
     /**
-     * Returns the Section for the Content Claim that this Event refers to, if
+     * @return the Section for the Content Claim that this Event refers to, if
      * any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     String getContentClaimSection();
 
     /**
-     * Returns the Section for the Content Claim that the FlowFile previously
+     * @return the Section for the Content Claim that the FlowFile previously
      * referenced, if any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     String getPreviousContentClaimSection();
 
     /**
-     * Returns the Container for the Content Claim that this Event refers to, if
+     * @return the Container for the Content Claim that this Event refers to, if
      * any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     String getContentClaimContainer();
 
     /**
-     * Returns the Container for the Content Claim that the FlowFile previously
+     * @return the Container for the Content Claim that the FlowFile previously
      * referenced, if any; otherwise, returns <code>null</code>
-     *
-     * @return
-     *
      */
     String getPreviousContentClaimContainer();
 
     /**
-     * Returns the Identifier for the Content Claim that this Event refers to,
+     * @return the Identifier for the Content Claim that this Event refers to,
      * if any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     String getContentClaimIdentifier();
 
     /**
-     * Returns the Identifier for the Content Claim that the FlowFile previously
+     * @return the Identifier for the Content Claim that the FlowFile previously
      * referenced, if any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     String getPreviousContentClaimIdentifier();
 
     /**
-     * Returns the offset into the Content Claim at which the FlowFile's content
+     * @return the offset into the Content Claim at which the FlowFile's content
      * begins, if any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     Long getContentClaimOffset();
 
     /**
-     * Returns the offset into the Content Claim at which the FlowFile's
+     * @return the offset into the Content Claim at which the FlowFile's
      * previous content began, if any; otherwise, returns <code>null</code>
      *
-     * @return
-     *
      */
     Long getPreviousContentClaimOffset();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRepository.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRepository.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRepository.java
index 39c829e..25563b7 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRepository.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/ProvenanceEventRepository.java
@@ -36,8 +36,9 @@ public interface ProvenanceEventRepository {
     /**
      * Performs any initialization needed. This should be called only by the
      * framework.
-     * @param eventReporter
-     * @throws java.io.IOException
+     *
+     * @param eventReporter to report to
+     * @throws java.io.IOException if unable to initialize
      */
     void initialize(EventReporter eventReporter) throws IOException;
 
@@ -45,7 +46,7 @@ public interface ProvenanceEventRepository {
      * Returns a {@link ProvenanceEventBuilder} that is capable of building
      * {@link ProvenanceEventRecord}s
      *
-     * @return
+     * @return builder
      */
     ProvenanceEventBuilder eventBuilder();
 
@@ -54,7 +55,7 @@ public interface ProvenanceEventRepository {
      * the event id has been populated. Depending on the implementation, the
      * returned event may or may not be the same event given
      *
-     * @param event
+     * @param event to register
      */
     void registerEvent(ProvenanceEventRecord event);
 
@@ -66,7 +67,7 @@ public interface ProvenanceEventRepository {
      * of the Collection are atomic. This detail is implementation-specific.
      * </p>
      *
-     * @param events
+     * @param events to register
      */
     void registerEvents(Iterable<ProvenanceEventRecord> events);
 
@@ -75,18 +76,16 @@ public interface ProvenanceEventRepository {
      * repository starting with the given ID. The first ID in the repository
      * will always be 0 or higher.
      *
-     * @param firstRecordId
-     * @param maxRecords
-     * @return
-     * @throws java.io.IOException
+     * @param firstRecordId id of the first record to retrieve
+     * @param maxRecords maximum number of records to retrieve
+     * @return records
+     * @throws java.io.IOException if error reading from repository
      */
     List<ProvenanceEventRecord> getEvents(long firstRecordId, final int maxRecords) throws IOException;
 
     /**
-     * Returns the largest ID of any event that is queryable in the repository.
+     * @return the largest ID of any event that is queryable in the repository.
      * If no queryable events exists, returns null
-     *
-     * @return
      */
     Long getMaxEventId();
 
@@ -94,19 +93,18 @@ public interface ProvenanceEventRepository {
      * Submits an asynchronous request to process the given query, returning an
      * identifier that can be used to fetch the results at a later time
      *
-     * @param query
-     * @return
+     * @param query to submit
+     * @return an identifier that can be used to fetch the results at a later
+     * time
      */
     QuerySubmission submitQuery(Query query);
 
     /**
-     * Returns the QueryResult associated with the given identifier, if the
-     * query has finished processing. If the query has not yet finished running,
-     * returns <code>null</code>.
+     * @param queryIdentifier of the query
      *
-     * @param queryIdentifier
-     *
-     * @return
+     * @return the QueryResult associated with the given identifier, if the
+     * query has finished processing. If the query has not yet finished running,
+     * returns <code>null</code>
      */
     QuerySubmission retrieveQuerySubmission(String queryIdentifier);
 
@@ -123,21 +121,17 @@ public interface ProvenanceEventRepository {
     ComputeLineageSubmission submitLineageComputation(String flowFileUuid);
 
     /**
-     * Returns the {@link ComputeLineageSubmission} associated with the given
+     * @param lineageIdentifier identifier of lineage to compute
+     * @return the {@link ComputeLineageSubmission} associated with the given
      * identifier
-     *
-     * @param lineageIdentifier
-     * @return
      */
     ComputeLineageSubmission retrieveLineageSubmission(String lineageIdentifier);
 
     /**
-     * Returns the Provenance Event Record with the given ID, if it exists, or
+     * @param id to lookup
+     * @return the Provenance Event Record with the given ID, if it exists, or
      * {@code null} otherwise
-     *
-     * @param id
-     * @return
-     * @throws IOException
+     * @throws IOException if failure while retrieving event
      */
     ProvenanceEventRecord getEvent(long id) throws IOException;
 
@@ -145,7 +139,7 @@ public interface ProvenanceEventRepository {
      * Submits a request to expand the parents of the event with the given id
      *
      * @param eventId the one-up id of the Event to expand
-     * @return
+     * @return a submission which can be checked for status
      *
      * @throws IllegalArgumentException if the given identifier identifies a
      * Provenance Event that has a Type that is not expandable or if the
@@ -157,7 +151,7 @@ public interface ProvenanceEventRepository {
      * Submits a request to expand the children of the event with the given id
      *
      * @param eventId the one-up id of the Event
-     * @return
+     * @return a submission which can be checked for status
      *
      * @throws IllegalArgumentException if the given identifier identifies a
      * Provenance Event that has a Type that is not expandable or if the
@@ -168,23 +162,19 @@ public interface ProvenanceEventRepository {
     /**
      * Closes the repository, freeing any resources
      *
-     * @throws IOException
+     * @throws IOException if failure closing repository
      */
     void close() throws IOException;
 
     /**
-     * Returns a list of all fields that can be searched via the
+     * @return a list of all fields that can be searched via the
      * {@link #submitQuery(nifi.provenance.search.Query)} method
-     *
-     * @return
      */
     List<SearchableField> getSearchableFields();
 
     /**
-     * Returns a list of all FlowFile attributes that can be searched via the
+     * @return a list of all FlowFile attributes that can be searched via the
      * {@link #submitQuery(nifi.provenance.search.Query)} method
-     *
-     * @return
      */
     List<SearchableField> getSearchableAttributes();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageResult.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageResult.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageResult.java
index c2d5513..e754ff7 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageResult.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageResult.java
@@ -25,46 +25,34 @@ import java.util.List;
 public interface ComputeLineageResult {
 
     /**
-     * Returns all nodes for the graph
-     *
-     * @return
+     * @return all nodes for the graph
      */
     public List<LineageNode> getNodes();
 
     /**
-     * Returns all links for the graph
-     *
-     * @return
+     * @return all links for the graph
      */
     public List<LineageEdge> getEdges();
 
     /**
-     * Returns the date at which this AsynchronousLineageResult will expire
-     *
-     * @return
+     * @return the date at which this AsynchronousLineageResult will expire
      */
     Date getExpiration();
 
     /**
-     * If an error occurred while computing the lineage, this will return the
-     * serialized error; otherwise, returns <code>null</code>.
-     *
-     * @return
+     * @return If an error occurred while computing the lineage, this will return the
+     * serialized error; otherwise, returns <code>null</code>
      */
     String getError();
 
     /**
-     * returns an integer between 0 and 100 (inclusive) that indicates what
+     * @return an integer between 0 and 100 (inclusive) that indicates what
      * percentage of completion the computation has reached
-     *
-     * @return
      */
     int getPercentComplete();
 
     /**
-     * Indicates whether or not the lineage has finished running
-     *
-     * @return
+     * @return Indicates whether or not the lineage has finished running
      */
     boolean isFinished();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageSubmission.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageSubmission.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageSubmission.java
index fbbff10..a9df26c 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageSubmission.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/ComputeLineageSubmission.java
@@ -22,25 +22,19 @@ import java.util.Date;
 public interface ComputeLineageSubmission {
 
     /**
-     * Returns the {@link ComputeLineageResult} that contains the results. The
+     * @return the {@link ComputeLineageResult} that contains the results. The
      * results may be partial if a call to
-     * {@link ComputeLineageResult#isFinished()} returns <code>false</code>.
-     *
-     * @return
+     * {@link ComputeLineageResult#isFinished()} returns <code>false</code>
      */
     ComputeLineageResult getResult();
 
     /**
-     * Returns the date at which this lineage was submitted
-     *
-     * @return
+     * @return the date at which this lineage was submitted
      */
     Date getSubmissionTime();
 
     /**
-     * Returns the generated identifier for this lineage result
-     *
-     * @return
+     * @return the generated identifier for this lineage result
      */
     String getLineageIdentifier();
 
@@ -56,27 +50,21 @@ public interface ComputeLineageSubmission {
     boolean isCanceled();
 
     /**
-     * Returns the type of Lineage Computation that was submitted
-     *
-     * @return
+     * @return the type of Lineage Computation that was submitted
      */
     LineageComputationType getLineageComputationType();
 
     /**
-     * If the Lineage Computation Type of this submission is
+     * @return If the Lineage Computation Type of this submission is
      * {@link LineageComputationType.EXPAND_CHILDREN} or
      * {@link LineageComputationType.EXPAND_PARENTS}, indicates the ID event
-     * that is to be expanded; otherwise, returns <code>null</code>.
-     *
-     * @return
+     * that is to be expanded; otherwise, returns <code>null</code>
      */
     Long getExpandedEventId();
 
     /**
-     * Returns all FlowFile UUID's that are encapsulated in this lineage
+     * @return all FlowFile UUID's that are encapsulated in this lineage
      * computation submission
-     *
-     * @return
      */
     Collection<String> getLineageFlowFileUuids();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/Lineage.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/Lineage.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/Lineage.java
index 252968c..ff5fee7 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/Lineage.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/Lineage.java
@@ -25,16 +25,12 @@ import java.util.List;
 public interface Lineage {
 
     /**
-     * Returns all nodes for the graph
-     *
-     * @return
+     * @return all nodes for the graph
      */
     public List<LineageNode> getNodes();
 
     /**
-     * Returns all links for the graph
-     *
-     * @return
+     * @return all links for the graph
      */
     public List<LineageEdge> getEdges();
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/LineageNode.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/LineageNode.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/LineageNode.java
index 84e3546..c50cdf5 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/LineageNode.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/lineage/LineageNode.java
@@ -19,43 +19,33 @@ package org.apache.nifi.provenance.lineage;
 public interface LineageNode {
 
     /**
-     * Returns the identifier of the Clustered NiFi Node that generated the
+     * @return the identifier of the Clustered NiFi Node that generated the
      * event
-     *
-     * @return
      */
     String getClusterNodeIdentifier();
 
     /**
-     * Returns the type of the LineageNode
-     *
-     * @return
+     * @return the type of the LineageNode
      */
     LineageNodeType getNodeType();
 
     /**
-     * Returns the UUID of the FlowFile for which this Node was created
-     *
-     * @return
+     * @return the UUID of the FlowFile for which this Node was created
      */
     String getFlowFileUuid();
 
     /**
-     * Returns the UUID for this LineageNode.
-     *
-     * @return
+     * @return the UUID for this LineageNode
      */
     String getIdentifier();
 
     /**
-     * Returns the timestamp that corresponds to this Node. The meaning of the
+     * @return the timestamp that corresponds to this Node. The meaning of the
      * timestamp may differ between implementations. For example, a
      * {@link ProvenanceEventLineageNode}'s timestamp indicates the time at
      * which the event occurred. However, for a Node that reperesents a
      * FlowFile, for example, the timestamp may represent the time at which the
-     * FlowFile was created.
-     *
-     * @return
+     * FlowFile was created
      */
     long getTimestamp();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/Query.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/Query.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/Query.java
index a319e36..3519c14 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/Query.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/Query.java
@@ -16,7 +16,12 @@
  */
 package org.apache.nifi.provenance.search;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Date;
+import java.util.List;
+import java.util.Objects;
+
 
 public class Query {
 

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/QueryResult.java
----------------------------------------------------------------------
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/QueryResult.java b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/QueryResult.java
index 3dd0b71..0079433 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/QueryResult.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/provenance/search/QueryResult.java
@@ -24,54 +24,40 @@ import org.apache.nifi.provenance.ProvenanceEventRecord;
 public interface QueryResult {
 
     /**
-     * Returns the Provenance events that match the query (up to the limit
+     * @return the Provenance events that match the query (up to the limit
      * specified in the query)
-     *
-     * @return
      */
     List<ProvenanceEventRecord> getMatchingEvents();
 
     /**
-     * Returns the total number of Provenance Events that hit
-     *
-     * @return
+     * @return the total number of Provenance Events that hit
      */
     long getTotalHitCount();
 
     /**
-     * Returns the number of milliseconds the query took to run
-     *
-     * @return
+     * @return the number of milliseconds the query took to run
      */
     long getQueryTime();
 
     /**
-     * Returns the date at which this QueryResult will expire
-     *
-     * @return
+     * @return the date at which this QueryResult will expire
      */
     Date getExpiration();
 
     /**
-     * If an error occurred while computing the lineage, this will return the
-     * serialized error; otherwise, returns <code>null</code>.
-     *
-     * @return
+     * @return If an error occurred while computing the lineage, this will return the
+     * serialized error; otherwise, returns <code>null</code>
      */
     String getError();
 
     /**
-     * returns an integer between 0 and 100 (inclusive) that indicates what
+     * @return an integer between 0 and 100 (inclusive) that indicates what
      * percentage of completion the query has reached
-     *
-     * @return
      */
     int getPercentComplete();
 
     /**
-     * Indicates whether or not the query has finished running
-     *
-     * @return
+     * @return Indicates whether or not the query has finished running
      */
     boolean isFinished();
 }
diff --git a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessSession.java b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessSession.java
index 7b855f2..ed46d68 100644
--- a/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessSession.java
+++ b/nifi/nifi-api/src/main/java/org/apache/nifi/processor/ProcessSession.java
@@ -60,7 +60,6 @@ import org.apache.nifi.provenance.ProvenanceReporter;
  * A process session instance may be used continuously. That is, after each
  * commit or rollback, the session can be used again.</p>
  *
- * @author unattributed
  */
 public interface ProcessSession {
 
@@ -136,7 +135,8 @@ public interface ProcessSession {
      * single call.
      *
      * @param maxResults the maximum number of FlowFiles to return
-     * @return
+     * @return up to <code>maxResults</code> FlowFiles from the work queue. If
+     * no FlowFiles are available, returns an empty list. Will not return null.
      * @throws IllegalArgumentException if <code>maxResults</code> is less than
      * 0
      */
@@ -152,8 +152,9 @@ public interface ProcessSession {
      * returned.
      * </p>
      *
-     * @param filter
-     * @return
+     * @param filter to limit which flow files are returned
+     * @return all FlowFiles from all of the incoming queues for which the given
+     * {@link FlowFileFilter} indicates should be accepted.
      */
     List<FlowFile> get(FlowFileFilter filter);
 
@@ -170,7 +171,7 @@ public interface ProcessSession {
      * linkage to a parent FlowFile. This method is appropriate only when data
      * is received or created from an external system. Otherwise, this method
      * should be avoided and should instead use {@link #create(FlowFile)} or
-     * {@link #create(Collection<FlowFile>)}.
+     * {@see #create(Collection)}.
      *
      * When this method is used, a Provenance CREATE or RECEIVE Event should be
      * generated. See the {@link #getProvenanceReporter()} method and
@@ -188,8 +189,8 @@ public interface ProcessSession {
      * event, depending on whether or not other FlowFiles are generated from the
      * same parent before the ProcessSession is committed.
      *
-     * @param parent
-     * @return
+     * @param parent to base the new flowfile on
+     * @return newly created flowfile
      */
     FlowFile create(FlowFile parent);
 
@@ -201,8 +202,8 @@ public interface ProcessSession {
      * only a single parent exists). This method will automatically generate a
      * Provenance JOIN event.
      *
-     * @param parents
-     * @return
+     * @param parents which the new flowfile should inherit shared attributes from
+     * @return new flowfile
      */
     FlowFile create(Collection<FlowFile> parents);
 
@@ -239,9 +240,9 @@ public interface ProcessSession {
      * Event, if the offset is 0 and the size is exactly equal to the size of
      * the example FlowFile).
      *
-     * @param example
-     * @param offset
-     * @param size
+     * @param parent to base the new flowfile attributes on
+     * @param offset of the parent flowfile to base the child flowfile content on
+     * @param size of the new flowfile from the offset
      * @return a FlowFile with the specified size whose parent is first argument
      * to this function
      *
@@ -250,14 +251,14 @@ public interface ProcessSession {
      * the given FlowFile
      * @throws FlowFileHandlingException if the given FlowFile is already
      * transferred or removed or doesn't belong to this session, or if the
      * specified offset + size exceeds that of the size of the example FlowFile.
      * Automatic rollback will occur.
      * @throws MissingFlowFileException if the given FlowFile content cannot be
      * found. The FlowFile should no longer be reference, will be internally
      * destroyed, and the session is automatically rolled back and what is left
      * of the FlowFile is destroyed.
      */
-    FlowFile clone(FlowFile example, long offset, long size);
+    FlowFile clone(FlowFile parent, long offset, long size);
 
     /**
      * Sets a penalty for the given FlowFile which will make it unavailable to
@@ -368,8 +369,8 @@ public interface ProcessSession {
      * destination processor will have immediate visibility of the transferred
      * FlowFiles within the session.
      *
-     * @param flowFile
-     * @param relationship
+     * @param flowFile to transfer
+     * @param relationship to transfer to
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -389,7 +390,7 @@ public interface ProcessSession {
      * the FlowFile will be maintained. FlowFiles that are created by the
      * processor cannot be transferred back to themselves via this method.
      *
-     * @param flowFile
+     * @param flowFile to transfer
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -410,7 +411,7 @@ public interface ProcessSession {
      * created by the processor cannot be transferred back to themselves via
      * this method.
      *
-     * @param flowFiles
+     * @param flowFiles to transfer
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -435,8 +436,8 @@ public interface ProcessSession {
      * destination processor will have immediate visibility of the transferred
      * FlowFiles within the session.
      *
-     * @param flowFiles
-     * @param relationship
+     * @param flowFiles to transfer
+     * @param relationship to transfer to
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -455,7 +456,7 @@ public interface ProcessSession {
      * nothing else references it and this FlowFile will no longer be available
      * for further operation.
      *
-     * @param flowFile
+     * @param flowFile to remove
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -471,7 +472,7 @@ public interface ProcessSession {
      * nothing else references it and this FlowFile will no longer be available
      * for further operation.
      *
-     * @param flowFiles
+     * @param flowFiles to remove
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -484,12 +485,12 @@ public interface ProcessSession {
     /**
      * Executes the given callback against the contents corresponding to the
      * given FlowFile.
-     * 
-     * <i>Note</i>: The OutputStream provided to the given OutputStreamCallback 
+     *
+     * <i>Note</i>: The OutputStream provided to the given OutputStreamCallback
      * will not be accessible once this method has completed its execution.
      *
-     * @param source
-     * @param reader
+     * @param source flowfile to retrieve content of
+     * @param reader that will be called to read the flowfile content
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -501,7 +502,7 @@ public interface ProcessSession {
      * destroyed, and the session is automatically rolled back and what is left
      * of the FlowFile is destroyed.
      * @throws FlowFileAccessException if some IO problem occurs accessing
-     * FlowFile content; if an attempt is made to access the  InputStream 
+     * FlowFile content; if an attempt is made to access the InputStream
      * provided to the given InputStreamCallback after this method completed its
      * execution
      */
@@ -511,8 +512,8 @@ public interface ProcessSession {
      * Combines the content of all given source FlowFiles into a single given
      * destination FlowFile.
      *
-     * @param sources
-     * @param destination
+     * @param sources the flowfiles to merge
+     * @param destination the flowfile to use as the merged result
      * @return updated destination FlowFile (new size, etc...)
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
@@ -536,8 +537,8 @@ public interface ProcessSession {
      * Combines the content of all given source FlowFiles into a single given
      * destination FlowFile.
      *
-     * @param sources
-     * @param destination
+     * @param sources to merge together
+     * @param destination to merge to
      * @param header bytes that will be added to the beginning of the merged
      * output. May be null or empty.
      * @param footer bytes that will be added to the end of the merged output.
@@ -566,12 +567,12 @@ public interface ProcessSession {
     /**
      * Executes the given callback against the content corresponding to the
      * given FlowFile.
-     * 
-     * <i>Note</i>: The OutputStream provided to the given OutputStreamCallback 
-     * will not be accessible once this method has completed its execution.     
      *
-     * @param source
-     * @param writer
+     * <i>Note</i>: The OutputStream provided to the given OutputStreamCallback
+     * will not be accessible once this method has completed its execution.
+     *
+     * @param source to write to
+     * @param writer used to write new content
      * @return updated FlowFile
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
@@ -584,8 +585,8 @@ public interface ProcessSession {
      * destroyed, and the session is automatically rolled back and what is left
      * of the FlowFile is destroyed.
      * @throws FlowFileAccessException if some IO problem occurs accessing
-     * FlowFile content; if an attempt is made to access the OutputStream 
-     * provided to the given OutputStreamCallaback after this method completed 
+     * FlowFile content; if an attempt is made to access the OutputStream
+     * provided to the given OutputStreamCallaback after this method completed
      * its execution
      */
     FlowFile write(FlowFile source, OutputStreamCallback writer) throws FlowFileAccessException;
@@ -593,13 +594,13 @@ public interface ProcessSession {
     /**
      * Executes the given callback against the content corresponding to the
      * given flow file.
-     * 
-     * <i>Note</i>: The InputStream & OutputStream provided to the given 
-     * StreamCallback will not be accessible once this method has completed its 
-     * execution.     
      *
-     * @param source
-     * @param writer
+     * <i>Note</i>: The InputStream & OutputStream provided to the given
+     * StreamCallback will not be accessible once this method has completed its
+     * execution.
+     *
+     * @param source to read from and write to
+     * @param writer used to read the old content and write new content
      * @return updated FlowFile
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
@@ -612,8 +613,8 @@ public interface ProcessSession {
      * destroyed, and the session is automatically rolled back and what is left
      * of the FlowFile is destroyed.
      * @throws FlowFileAccessException if some IO problem occurs accessing
-     * FlowFile content; if an attempt is made to access the InputStream or 
-     * OutputStream provided to the given StreamCallback after this method 
+     * FlowFile content; if an attempt is made to access the InputStream or
+     * OutputStream provided to the given StreamCallback after this method
      * completed its execution
      */
     FlowFile write(FlowFile source, StreamCallback writer) throws FlowFileAccessException;
@@ -622,16 +623,16 @@ public interface ProcessSession {
      * Executes the given callback against the content corresponding to the
      * given FlowFile, such that any data written to the OutputStream of the
      * content will be appended to the end of FlowFile.
-     * 
-     * <i>Note</i>: The OutputStream provided to the given OutputStreamCallback 
+     *
+     * <i>Note</i>: The OutputStream provided to the given OutputStreamCallback
      * will not be accessible once this method has completed its execution.
      *
-     * @param source
-     * @param writer
-     * @return
-     * @throws FlowFileAccessException if an attempt is made to access the 
-     * OutputStream provided to the given OutputStreamCallaback after this method
-     * completed its execution
+     * @param source the flowfile for which content should be appended
+     * @param writer used to write new bytes to the flowfile content
+     * @return the updated flowfile reference for the new content
+     * @throws FlowFileAccessException if an attempt is made to access the
+     * OutputStream provided to the given OutputStreamCallaback after this
+     * method completed its execution
      */
     FlowFile append(FlowFile source, OutputStreamCallback writer) throws FlowFileAccessException;
 
@@ -687,8 +688,8 @@ public interface ProcessSession {
     /**
      * Writes the content of the given FlowFile to the given destination path.
      *
-     * @param flowFile
-     * @param destination
+     * @param flowFile to export the content of
+     * @param destination to export the content to
      * @param append if true will append to the current content at the given
      * path; if false will replace any current content
      * @throws IllegalStateException if detected that this method is being
@@ -709,8 +710,8 @@ public interface ProcessSession {
     /**
      * Writes the content of the given FlowFile to the given destination stream
      *
-     * @param flowFile
-     * @param destination
+     * @param flowFile to export the content of
+     * @param destination to export the content to
      * @throws IllegalStateException if detected that this method is being
      * called from within a callback of another method in this session and for
      * the given FlowFile(s)
@@ -729,7 +730,7 @@ public interface ProcessSession {
     /**
      * Returns a ProvenanceReporter that is tied to this ProcessSession.
      *
-     * @return
+     * @return the provenance reporter
      */
     ProvenanceReporter getProvenanceReporter();
 }

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/bcb3ca8f/nifi/nifi-api/src/main/java/org/apache/nifi/processor/Processor.java
----------------------------------------------------------------------
@@ -250,14 +251,14 @@ public interface ProcessSession {
      * @throws FlowFileHandlingException if the given FlowFile is already
      * transferred or removed or doesn't belong to this session, or if the
-     * specified offset + size exceeds that of the size of the example FlowFile.
+     * specified offset + size exceeds that of the size of the parent FlowFile.
      * Automatic rollback will occur.
      * @throws MissingFlowFileException if the given FlowFile content cannot be